@@ -58,7 +58,8 @@ class DeviceAws(CallbacksMixin):
     pm1 : AttributeType[int] = None
     pm2_5 : AttributeType[int] = None
     pm10 : AttributeType[int] = None
-    tVOC : AttributeType[int] = None
+    total_voc : AttributeType[int] = None
+    voc : AttributeType[int] = None
     temperature : AttributeType[int] = None
     humidity : AttributeType[int] = None
     filter_usage_percentage : AttributeType[int] = None
@@ -98,7 +99,8 @@ class DeviceAws(CallbacksMixin):
         self.pm1 = sensor_data_safe_get("pm1")
         self.pm2_5 = sensor_data_safe_get("pm2_5")
         self.pm10 = sensor_data_safe_get("pm10")
-        self.tVOC = sensor_data_safe_get("tVOC")
+        self.total_voc = sensor_data_safe_get("tVOC")
+        self.voc = sensor_data_safe_get("voc")
         self.temperature = sensor_data_safe_get("t")
         self.humidity = sensor_data_safe_get("h")
         self.fan_speed_0 = sensor_data_safe_get("fsp0")
@@ -242,7 +244,7 @@ class DeviceAws(CallbacksMixin):
 
     @property
     def model(self) -> ModelEnum:
-        if self.sku == "111633":
+        if self.sku in ["111633", "112851"]:
             return ModelEnum.HUMIDIFIER_H35I
         if self.sku == "105820":
             return ModelEnum.PROTECT_7440I
@@ -260,4 +262,12 @@ class DeviceAws(CallbacksMixin):
             return ModelEnum.T10I
         if self.sku in ["109539", "110034"]:
             return ModelEnum.MAX_311I_PLUS
+        if self.sku == "112929":
+            return ModelEnum.BLUE_SIGNATURE
+        if self.sku == "112793":
+            return ModelEnum.PET_AIR_PRO
+        if self.sku == "110178":
+            return ModelEnum.MAX_3250I
+        if self.sku == "111905":
+            return ModelEnum.MAX_3650I
         return ModelEnum.UNKNOWN
