@@ -9,6 +9,10 @@ class ModelEnum(StrEnum):
     MAX_211I = "Blueair Blue Pure 211i Max"
     MAX_311I = "Blueair Blue Pure 311i Max"
     MAX_311I_PLUS = "Blueair Blue Pure 311i+ Max"
+    MAX_3250I = "Blueair Blue Pure 3250i Max"
+    MAX_3650I = "Blueair Blue Pure 3650i Max"
     MAX_411I = "Blueair Blue Pure 411i Max"
     MAX_511I = "Blueair Blue Pure 511i Max"
     T10I = "T10i ComfortPure 3-in-1 Filter/Heater/Fan"
+    BLUE_SIGNATURE = "Blue Signature"
+    PET_AIR_PRO = "PetAir Pro"
